pub type TestResponseSender = Sender<TestResponse>;Expand description
Per-command response channel used by the shell event loop.
Aliased Type
pub struct TestResponseSender { /* private fields */ }pub type TestResponseSender = Sender<TestResponse>;Per-command response channel used by the shell event loop.
pub struct TestResponseSender { /* private fields */ }