Automated UI testing client and protocol for Fission applications.
This crate provides the JSON protocol types (shared between the test client
and the desktop shell server) and a LiveTestClient that drives a running
Fission application over HTTP.
Architecture
The application must be launched with FISSION_TEST_CONTROL_PORT=<port>.
The LiveTestClient connects to http://127.0.0.1:<port> and sends
TestCommand JSON payloads to /cmd, receiving TestResponse replies.
Structs
- Live
Test Client - An HTTP client that drives a running Fission application for automated UI testing.
- Semantic
Node - A node in the semantic accessibility tree, returned by
TestCommand::GetTree. - Text
Item - A visible text element with its bounding rectangle, returned by
TestCommand::GetText.
Enums
- Test
Command - A command sent from the test client to the running application.
- Test
Response - The response from the application to a
TestCommand.